Class: Utter::Ext
- Inherits:
-
Mushin::Ext
- Object
- Mushin::Ext
- Utter::Ext
- Defined in:
- lib/utter.rb
Overview
Makes sure that any class that inherits form “< Utter::Ext” must implement :initialize and :call
Makes sure that any class that inherits form “< Utter::Ext” must implement :initialize and :call