Class: Utter::Stack

Inherits:
Mushin::Stack
  • Object
show all
Defined in:
lib/utter.rb

Overview

BASIC FEATURE Usage of non domain-specific stack inside a microservice would be like Stack.new do

use Trace,  "A opts hash",  x
use Trace,  "B opts hash", "B params hash"
use Trace,  "C opts hash", "C params hash"

end Very helpful if you just want to build extenstions conforming to Mushin ducking interface of :initialize(app), :call(env) Yet it is strongly encourged to require your own domain-specific frameworks generated via mushin inexample, and use only a constraining yourself for a single domain-framework per microservice. example

require ‘domainframeworkXYZ’ require ‘domainframeworkXYZ_ext_1’ require ‘domainframeworkXYZ_ext_2’ require ‘domainframeworkXYZ_ext_3’ DomainFrameworkXYZ::Stack do

use DomainFrameworkXYZ_EXT_1, opts, params
use DomainFrameworkXYZ_EXT_2, opts, params
use DomainFrameworkXYZ_EXT_3, opts, params

end this way your work on that domain is ackonwledgeenhanced by the community at large.